Macro request_fast_gpu

macro_rules! request_fast_gpu {
    () => { ... };
}
Available on crate feature request_fast_gpu only.
Request for usage of high performance gpu in multi gpu setups.

Platform behavior:

Windows:

  • Adds the variables NvOptimusEnablement and AmdPowerXpressRequestHighPerformance with a value of one.
  • Required the user to also export those by setting the linker args. This can be done in build.rs via:
println!("cargo:rustc-link-arg=/EXPORT:NvOptimusEnablement");
println!("cargo:rustc-link-arg=/EXPORT:AmdPowerXpressRequestHighPerformance");

Other platforms:

Currently does nothing on other platforms.

Validating

Check with dumpbin /exports $APPLICATION.exe